@@ -7,7 +7,7 @@
  */
 
 /*
- *  GiNaC Copyright (C) 1999-2007 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2008 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,7 +24,12 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "times.h"
+#include <iostream>
+#include <vector>
+#include "ginac.h"
+#include "timer.h"
+using namespace std;
+using namespace GiNaC;
 
 static unsigned vandermonde_det(unsigned size)
 {
@@ -66,16 +71,15 @@ unsigned time_vandermonde()
 	unsigned result = 0;
 	
 	cout << "timing determinant of univariate symbolic Vandermonde matrices" << flush;
-	clog << "-------determinant of univariate symbolic Vandermonde matrices:" << endl;
 	
 	vector<unsigned> sizes;
 	vector<double> times;
 	timer swatch;
 	
-	sizes.push_back(6);
 	sizes.push_back(8);
 	sizes.push_back(10);
 	sizes.push_back(12);
+	sizes.push_back(14);
 	
 	for (vector<unsigned>::iterator i=sizes.begin(); i!=sizes.end(); ++i) {
 		int count = 1;
@@ -90,20 +94,23 @@ unsigned time_vandermonde()
 		cout << '.' << flush;
 	}
 	
-	if (!result) {
-		cout << " passed ";
-		clog << "(no output)" << endl;
-	} else {
-		cout << " failed ";
-	}
 	// print the report:
 	cout << endl << "	dim:   ";
 	for (vector<unsigned>::iterator i=sizes.begin(); i!=sizes.end(); ++i)
 		cout << '\t' << *i << 'x' << *i;
 	cout << endl << "	time/s:";
 	for (vector<double>::iterator i=times.begin(); i!=times.end(); ++i)
-		cout << '\t' << int(1000*(*i))*0.001;
+		cout << '\t' << *i;
 	cout << endl;
 	
 	return result;
 }
+
+extern void randomify_symbol_serials();
+
+int main(int argc, char** argv)
+{
+	randomify_symbol_serials();
+	cout << setprecision(2) << showpoint;
+	return time_vandermonde();
+}
