@@ -3,7 +3,7 @@
  *  Interface to sequences of expression pairs. */
 
 /*
- *  GiNaC Copyright (C) 1999-2007 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2008 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include <algorithm>
 
 #include "expair.h"
+#include "indexed.h"
 
 namespace GiNaC {
 
@@ -70,8 +71,8 @@ class expairseq : public basic
 public:
 	expairseq(const ex & lh, const ex & rh);
 	expairseq(const exvector & v);
-	expairseq(const epvector & v, const ex & oc);
-	expairseq(std::auto_ptr<epvector>, const ex & oc);
+	expairseq(const epvector & v, const ex & oc, bool do_index_renaming = false);
+	expairseq(std::auto_ptr<epvector>, const ex & oc, bool do_index_renaming = false);
 	
 	// functions overriding virtual functions from base classes
 public:
@@ -86,6 +87,7 @@ public:
 	bool match(const ex & pattern, lst & repl_lst) const;
 	ex subs(const exmap & m, unsigned options = 0) const;
 	ex conjugate() const;
+	bool is_polynomial(const ex & var) const;
 protected:
 	bool is_equal_same_type(const basic & other) const;
 	unsigned return_type() const;
@@ -94,8 +96,8 @@ protected:
 	
 	// new virtual functions which can be overridden by derived classes
 protected:
-	virtual ex thisexpairseq(const epvector & v, const ex & oc) const;
-	virtual ex thisexpairseq(std::auto_ptr<epvector> vp, const ex & oc) const;
+	virtual ex thisexpairseq(const epvector & v, const ex & oc, bool do_index_renaming = false) const;
+	virtual ex thisexpairseq(std::auto_ptr<epvector> vp, const ex & oc, bool do_index_renaming = false) const;
 	virtual void printseq(const print_context & c, char delim,
 	                      unsigned this_precedence,
 	                      unsigned upper_precedence) const;
@@ -124,9 +126,9 @@ protected:
 	void construct_from_expairseq_ex(const expairseq & s,
 	                                 const ex & e);
 	void construct_from_exvector(const exvector & v);
-	void construct_from_epvector(const epvector & v);
+	void construct_from_epvector(const epvector & v, bool do_index_renaming = false);
 	void make_flat(const exvector & v);
-	void make_flat(const epvector & v);
+	void make_flat(const epvector & v, bool do_index_renaming = false);
 	void canonicalize();
 	void combine_same_terms_sorted_seq();
 #if EXPAIRSEQ_USE_HASHTAB
@@ -170,13 +172,59 @@ protected:
 #endif // EXPAIRSEQ_USE_HASHTAB
 };
 
-// utility functions
-
-/** Specialization of is_exactly_a<expairseq>(obj) for expairseq objects. */
-template<> inline bool is_exactly_a<expairseq>(const basic & obj)
+/** Class to handle the renaming of dummy indices. It holds a vector of
+ *  indices that are being used in the expression so-far. If the same
+ *  index occurs again as a dummy index in a factor, it is to be renamed.
+ *  Unless dummy index renaming was swichted of, of course ;-) . */
+class make_flat_inserter
 {
-	return obj.tinfo()==TINFO_expairseq;
-}
+	public:
+		make_flat_inserter(const epvector &epv, bool b): do_renaming(b)
+		{
+			if (!do_renaming)
+				return;
+			for (epvector::const_iterator i=epv.begin(); i!=epv.end(); ++i)
+				if(are_ex_trivially_equal(i->coeff, 1))
+					combine_indices(i->rest.get_free_indices());
+		}
+		make_flat_inserter(const exvector &v, bool b): do_renaming(b)
+		{
+			if (!do_renaming)
+				return;
+			for (exvector::const_iterator i=v.begin(); i!=v.end(); ++i)
+				combine_indices(i->get_free_indices());
+		}
+		ex handle_factor(const ex &x, const ex &coeff)
+		{
+			if (!do_renaming)
+				return x;
+			exvector dummies_of_factor;
+			if (is_a<numeric>(coeff) && coeff.is_equal(GiNaC::numeric(1)))
+				dummies_of_factor = get_all_dummy_indices_safely(x);
+			else if (is_a<numeric>(coeff) && coeff.is_equal(GiNaC::numeric(2)))
+				dummies_of_factor = x.get_free_indices();
+			else
+				return x;
+			if (dummies_of_factor.size() == 0)
+				return x;
+			sort(dummies_of_factor.begin(), dummies_of_factor.end(), ex_is_less());
+			ex new_factor = rename_dummy_indices_uniquely(used_indices,
+				dummies_of_factor, x);
+			combine_indices(dummies_of_factor);
+			return new_factor;
+		}
+	private:
+		void combine_indices(const exvector &dummies_of_factor)
+		{
+			exvector new_dummy_indices;
+			set_union(used_indices.begin(), used_indices.end(),
+				dummies_of_factor.begin(), dummies_of_factor.end(),
+				std::back_insert_iterator<exvector>(new_dummy_indices), ex_is_less());
+			used_indices.swap(new_dummy_indices);
+		}
+		bool do_renaming;
+		exvector used_indices;
+};
 
 } // namespace GiNaC
 
